# Mouse data preprocessing



########################################################################
###### Environment #####################################################
########################################################################
## library
lib <- readRDS("...zenodo/Others/Library.rds")
for(i in 1: length(lib)){
  library(lib[i], character.only = T)
}

setwd("...zenodo/Mouse_normal_breast_data") 
params <- read.table("...zenodo/Others/Mouse_preprocessing_parameters.txt", header=T) # Provided at Github
params2 <- readRDS("...zenodo/Others/Mouse_preprocessing_ClustList.rds")

## Create subfolders
dir <- levels(params$Dataset)
for(i in 1:length(dir)){
  dir.create(dir[i])
}

## Cell cycle gene preparation 
ConvertHumanGeneListToMM <- function(x){
  # Load human ensembl attributes
  human = biomaRt::useMart("ensembl", dataset = "hsapiens_gene_ensembl")
  # Load mouse ensembl attributes
  mouse = biomaRt::useMart("ensembl", dataset = "mmusculus_gene_ensembl")
  # Link both datasets and retrieve mouse genes from the human genes
  genes.list = biomaRt::getLDS(attributes = c("hgnc_symbol"), filters = "hgnc_symbol", values = x , mart = human, attributesL = c("mgi_symbol"), martL = mouse, uniqueRows = T)
  # Get unique names of genes (in case gene names are duplicated)
  mouse.gene.list <- unique(genes.list[, 2])
  # # Print the first 6 genes found to the screen
  # print(head(mouse.gene.list))
  return(mouse.gene.list)
}
data(cc.genes)
mouse.cc.genes <- lapply(X = cc.genes, 
                         ConvertHumanGeneListToMM)
s.genes <- mouse.cc.genes$s.genes
g2m.genes <- mouse.cc.genes$g2m.genes



########################################################################
###### Raw data retrieval ##############################################
########################################################################
## Giraddi et al.
# Data was obtained from the Gene Expression Omnibus database (accession number: GSE111113)
# ("https://www.ncbi.nlm.nih.gov/geo/query/acc.cgi?acc=GSE111113")
#
# The row with blank gene symbol is manually removed from "GSE111113_Table_S1_FilterNormal10xExpMatrix.txt"
# using a text edititor (e.g. Excel).
# Then, "barcode.txt", "genes.tsv", "count.txt" were manually generated to fit Read10x function of Seurat package.
#
# > "matrix.mtx" was further generated from "count.txt" with the code below
# > count <- read.table("...your_folder/Giraddi/raw_data/count.txt")
# > count <- as.matrix(count)
# > mtx <- as(count, "sparseMatrix")
# > writeMM(mtx, "matrix.mtx")
#
# Store "barcode.txt", "genes.tsv" and "count.txt" in one folder("...your_folder/Giraddi/data").
# These intermediate files are available upon a reasonable request.

## Pal et al.
# Data was obtained from the Gene Expression Omnibus database (accession number: GSE103275)
# ("https://www.ncbi.nlm.nih.gov/geo/query/acc.cgi?acc=GSE103275")
# Adult epithelial cells: GSM2510617
# Adult basal cells: GSM2510616
# Puberty epithelial cells_1: GSM2759554
# Puberty epithelial cells_2: GSM2759555
# Adult diestrus epithelial cells: GSM2759556
# Adult estrus epithelial cells: GSM5759557

## Bach et al.
# Data was obtained from the Gene Expression Omnibus database (accession number: GSE106273)
# ("https://www.ncbi.nlm.nih.gov/geo/query/acc.cgi?acc=GSE106273")
# NP_1: GSM2834498
# NP_2: GSM2834499
# G_1: GSM2834500
# G_2: GSM2834501
# L_1: GSM2834502
# L_2: GSM2834503
# NP_1: GSM2834504
### NP_2: GSM2834505

## Tabula Muris
# Data was obtained from the Gene Expression Omnibus database (accession number: GSE109774)
# ("https://www.ncbi.nlm.nih.gov/geo/query/acc.cgi?acc=GSE109774")
# 10X_P7_12: GSM3090410
# 10X_P7_13: GSM3090411

## Saeki et al. (This study)
# Data was obtained from the Gene Expression Omnibus database (accession number: GSE149949)
# ("https://www.ncbi.nlm.nih.gov/geo/query/acc.cgi?acc=GSE149949")
# GSM4518605	Vehicle
# GSM4518606	E2
# GSM4518607	E2+PBDE
# GSM4518608	E2+P4
# GSM4518609	E2+P4+PBDE


########################################################################
###### Seurat object preparation #######################################
########################################################################
## Giraddi 
data_dir <- "...your_folder/Giraddi/data"
list.files(data_dir)
#[1] "barcodes.tsv" "genes.tsv"    "matrix.mtx"
expression_matrix <- Read10X(data.dir = data_dir)
seu_Giraddi = CreateSeuratObject(counts = expression_matrix, project = "Giraddi", min.cells = 3, min.features = 200)
seu_Giraddi[["percent.mt"]] <- PercentageFeatureSet(seu_Giraddi, pattern = "^mt-")
seu_Giraddi <- subset(seu_Giraddi, subset = nCount_RNA > 1000 & nFeature_RNA > 500 & percent.mt < 10)
Idents(seu_Giraddi) <- "orig.ident"
current.cluster.ids <- c("E16","E18","P4","Adu1","Adu2", "AduBas")
new.cluster.ids <- c("Embryonic_d16(G)", "Embryonic_d18(G)",  "Postnatal_d4(G)","Adult_1(G)", "Adult_2(G)", "Adult_Basal(G)")
seu_Giraddi@active.ident <- plyr::mapvalues(x = seu_Giraddi@active.ident, from = current.cluster.ids, to = new.cluster.ids)
seu_Giraddi$orig.ident <- seu_Giraddi@active.ident

E16 <- subset(seu_Giraddi, idents = "Embryonic_d16(G)")
E18 <- subset(seu_Giraddi, idents = "Embryonic_d18(G)")
P4 <- subset(seu_Giraddi, idents = "Postnatal_d4(G)")
Adu1 <- subset(seu_Giraddi, idents = "Adult_1(G)")
Adu2 <- subset(seu_Giraddi, idents = "Adult_2(G)")
AduBas <- subset(seu_Giraddi, idents = "Adult_Basal(G)")

###
saveRDS(E16, "Embryonic_d16(G)/Embryonic_d16(G).rds")
saveRDS(E18, "Embryonic_d18(G)/Embryonic_d18(G).rds")
saveRDS(P4, "Postnatal_d4(G)/Postnatal_d4(G).rds")
saveRDS(Adu1, "Adult_1(G)/Adult_1(G).rds")
saveRDS(Adu2, "Adult_2(G)/Adult_2(G).rds")
saveRDS(AduBas, "Adult_Basal(G)/Adult_Basal(G).rds")

remove(expression_matrix, seu_Giraddi, current.cluster.ids,new.cluster.ids, E16, E18, P4, Adu1, Adu2, AduBas)

## Pal 
### Adult epithelial 
Pal_dir <- "...your_folder/Pal/data/Adult_Epi"
list.files(Pal_dir) 
# barcodes.tsv, genes.tsv, and matrix.mtx
expression_matrix <- Read10X(data.dir = Pal_dir)
AduEpi = CreateSeuratObject(counts = expression_matrix, project = "Adult(P)", min.cells = 3, min.features = 200)
AduEpi[["percent.mt"]] <- PercentageFeatureSet(AduEpi, pattern = "^mt-")
AduEpi <- subset(AduEpi, subset = nCount_RNA > 1000 & nFeature_RNA > 500 & percent.mt < 5)

### Adult puberty_1 
Pal_dir <- "...your_folder/Pal/data/Puberty_1"
list.files(Pal_dir) # Should show barcodes.tsv, genes.tsv, and matrix.mtx
expression_matrix <- Read10X(data.dir = Pal_dir)
Pub1 = CreateSeuratObject(counts = expression_matrix, project = "Puberty_1(P)", min.cells = 3, min.features = 200)
Pub1[["percent.mt"]] <- PercentageFeatureSet(Pub1, pattern = "^mt-")
Pub1 <- subset(Pub1, subset = nCount_RNA > 1000 & nFeature_RNA > 500 & percent.mt < 5)

### Adult puberty_2 
Pal_dir <- "...your_folder/Pal/data/Puberty_2"
list.files(Pal_dir) # Should show barcodes.tsv, genes.tsv, and matrix.mtx
expression_matrix <- Read10X(data.dir = Pal_dir)
Pub2 = CreateSeuratObject(counts = expression_matrix, project = "Puberty_2(P)", min.cells = 3, min.features = 200)
Pub2[["percent.mt"]] <- PercentageFeatureSet(Pub2, pattern = "^mt-")
Pub2 <- subset(Pub2, subset = nCount_RNA > 1000 & nFeature_RNA > 500 & percent.mt < 5)

### Adult Diestrus 
Pal_dir <- "...your_folder/Pal/data/Adult_Diestrus"
list.files(Pal_dir) # Should show barcodes.tsv, genes.tsv, and matrix.mtx
expression_matrix <- Read10X(data.dir = Pal_dir)
Diestrus = CreateSeuratObject(counts = expression_matrix, project = "Adult_Diestrus(P)", min.cells = 3, min.features = 200)
Diestrus[["percent.mt"]] <- PercentageFeatureSet(Diestrus, pattern = "^mt-")
Diestrus <- subset(Diestrus, subset = nCount_RNA > 1000 & nFeature_RNA > 500 & percent.mt < 5)

### Adult Estrus 
Pal_dir <- "...your_folder/Pal/data/Adult_Estrus"
list.files(Pal_dir) # Should show barcodes.tsv, genes.tsv, and matrix.mtx
expression_matrix <- Read10X(data.dir = Pal_dir)
Estrus = CreateSeuratObject(counts = expression_matrix, project = "Adult_Estrus(P)", min.cells = 3, min.features = 200)
Estrus[["percent.mt"]] <- PercentageFeatureSet(Estrus, pattern = "^mt-")
Estrus <- subset(Estrus, subset = nCount_RNA > 1000 & nFeature_RNA > 500 & percent.mt < 5)


###
saveRDS(AduEpi, "Adult(P)/Adult(P).rds")
saveRDS(Pub1, "Puberty_1(P)/Puberty_1(P).rds")
saveRDS(Pub2, "Puberty_2(P)/Puberty_2(P).rds")
saveRDS(Diestrus, "Adult_Diestrus(P)/Adult_Diestrus(P).rds")
saveRDS(Estrus, "Adult_Estrus(P)/Adult_Estrus(P).rds")

remove(Pal_dir, expression_matrix, AduEpi, Diestrus, Estrus, Pub1, Pub2)

## Bach
### Nulliparous_1 
Bach_dir <- "...your_folder/Bach/data/NP_1"
list.files(Bach_dir) # Should show barcodes.tsv, genes.tsv, and matrix.mtx
expression_matrix <- Read10X(data.dir = Bach_dir)
NP1 = CreateSeuratObject(counts = expression_matrix, project = "Nulliparous_1(B)", min.cells = 3, min.features = 200)
NP1[["percent.mt"]] <- PercentageFeatureSet(NP1, pattern = "^mt-")
NP1 <- subset(NP1, subset = nCount_RNA > 1000 & nFeature_RNA > 500 & percent.mt < 5)

### Nulliparous_2
Bach_dir <- "...your_folder/Bach/data/NP_2"
list.files(Bach_dir) # Should show barcodes.tsv, genes.tsv, and matrix.mtx
expression_matrix <- Read10X(data.dir = Bach_dir)
NP2 = CreateSeuratObject(counts = expression_matrix, project = "Nulliparous_2(B)", min.cells = 3, min.features = 200)
NP2[["percent.mt"]] <- PercentageFeatureSet(NP2, pattern = "^mt-")
NP2 <- subset(NP2, subset = nCount_RNA > 1000 & nFeature_RNA > 500 & percent.mt < 5)

### Gestation_1 
Bach_dir <- "...your_folder/Bach/data/G_1"
list.files(Bach_dir) # Should show barcodes.tsv, genes.tsv, and matrix.mtx
expression_matrix <- Read10X(data.dir = Bach_dir)
G1 = CreateSeuratObject(counts = expression_matrix, project = "Gestation_1(B)", min.cells = 3, min.features = 200)
G1[["percent.mt"]] <- PercentageFeatureSet(G1, pattern = "^mt-")
G1 <- subset(G1, subset = nCount_RNA > 1000 & nFeature_RNA > 500 & percent.mt < 5)

### Gestation_2 
Bach_dir <- "...your_folder/Bach/data/G_2"
list.files(Bach_dir) # Should show barcodes.tsv, genes.tsv, and matrix.mtx
expression_matrix <- Read10X(data.dir = Bach_dir)
G2 = CreateSeuratObject(counts = expression_matrix, project = "Gestation_2(B)", min.cells = 3, min.features = 200)
G2[["percent.mt"]] <- PercentageFeatureSet(G2, pattern = "^mt-")
G2 <- subset(G2, subset = nCount_RNA > 1000 & nFeature_RNA > 500 & percent.mt < 5)

### PostInvolution_1 
Bach_dir <- "...your_folder/Bach/data/PI_1"
list.files(Bach_dir) # Should show barcodes.tsv, genes.tsv, and matrix.mtx
expression_matrix <- Read10X(data.dir = Bach_dir)
PI1 = CreateSeuratObject(counts = expression_matrix, project = "PostInvolution_1(B)", min.cells = 3, min.features = 200)
PI1[["percent.mt"]] <- PercentageFeatureSet(PI1, pattern = "^mt-")
PI1 <- subset(PI1, subset = nCount_RNA > 1000 & nFeature_RNA > 500 & percent.mt < 5)

### PostInvolution_2
Bach_dir <- "...your_folder/Bach/data/PI_2"
list.files(Bach_dir) # Should show barcodes.tsv, genes.tsv, and matrix.mtx
expression_matrix <- Read10X(data.dir = Bach_dir)
PI2 = CreateSeuratObject(counts = expression_matrix, project = "PostInvolution_2(B)", min.cells = 3, min.features = 200)
PI2[["percent.mt"]] <- PercentageFeatureSet(PI2, pattern = "^mt-")
PI2 <- subset(PI2, subset = nCount_RNA > 1000 & nFeature_RNA > 500 & percent.mt < 5)

### Lactation_1 
Bach_dir <- "...your_folder/Bach/data/L_1"
list.files(Bach_dir) # Should show barcodes.tsv, genes.tsv, and matrix.mtx
expression_matrix <- Read10X(data.dir = Bach_dir)
L1 = CreateSeuratObject(counts = expression_matrix, project = "Lactation_1(B)", min.cells = 3, min.features = 200)
L1[["percent.mt"]] <- PercentageFeatureSet(L1, pattern = "^mt-")
L1 <- subset(L1, subset = nCount_RNA > 1000 & nFeature_RNA > 500 & percent.mt < 5)

### Lactation_2
Bach_dir <- "...your_folder/Bach/data/L_2"
list.files(Bach_dir) # Should show barcodes.tsv, genes.tsv, and matrix.mtx
expression_matrix <- Read10X(data.dir = Bach_dir)
L2 = CreateSeuratObject(counts = expression_matrix, project = "Lactation_2(B)", min.cells = 3, min.features = 200)
L2[["percent.mt"]] <- PercentageFeatureSet(L2, pattern = "^mt-")
L2 <- subset(L2, subset = nCount_RNA > 1000 & nFeature_RNA > 500 & percent.mt < 5)


###
saveRDS(NP1, "Nulliparous_1(B)/Nulliparous_1(B).rds")
saveRDS(NP2, "Nulliparous_2(B)/Nulliparous_2(B).rds")
saveRDS(G1, "Gestation_1(B)/Gestation_1(B).rds")
saveRDS(G2, "Gestation_2(B)/Gestation_2(B).rds")
saveRDS(PI1, "PostInvolution_1(B)/PostInvolution_1(B).rds")
saveRDS(PI2, "PostInvolution_2(B)/PostInvolution_2(B).rds")
saveRDS(L1, "Lactation_1(B)/Lactation_1(B).rds")
saveRDS(L2, "Lactation_2(B)/Lactation_2(B).rds")

remove(expression_matrix, Bach_dir, NP1, NP2, G1, G2, PI1, PI2, L1, L2)


## Tabula Muris 
load("...your_folder/TabulaMuris/droplet_Mammary_seurat_tiss.Robj")
tiss <- UpdateSeuratObject(tiss)
colnames(tiss@meta.data)[1:2] <- c("nFeature_RNA", "nCount_RNA")
tiss[["percent.mt"]] <- PercentageFeatureSet(tiss, pattern = "^mt-")
Idents(tiss) <- "channel"
new.cluster.ids <- c("Adult_1(TM)", "Adult_2(TM)")
names(new.cluster.ids) <- levels(tiss)
tiss <- RenameIdents(tiss, new.cluster.ids)
tiss$orig.ident <- tiss@active.ident

Adu1 <- subset(tiss, idents = "Adult_1(TM)")
Adu2 <- subset(tiss, idents = "Adult_2(TM)")

###
saveRDS(Adu1, "Adult_1(TM)/Adult_1(TM).rds")
saveRDS(Adu2, "Adult_2(TM)/Adult_2(TM).rds")

remove(tiss, new.cluster.ids, Adu1, Adu2)


## Saeki 
### Vehicle
data_dir <- "...your_folder/Saeki/data/OVX_20"
list.files(data_dir) # Should show barcodes.tsv, genes.tsv, and matrix.mtx
expression_matrix <- Read10X(data.dir = data_dir)
OVX_20 = CreateSeuratObject(counts = expression_matrix, project = "OVX(S)", min.cells = 3, min.features = 200)
OVX_20[["percent.mt"]] <- PercentageFeatureSet(OVX_20, pattern = "^mt-")
OVX_20 <- subset(OVX_20, subset = nFeature_RNA > 500 & nCount_RNA > 1000 & percent.mt < 10)

### E2
data_dir <- "...your_folder/Saeki/data/OVX_E2_20"
list.files(data_dir) # Should show barcodes.tsv, genes.tsv, and matrix.mtx
expression_matrix <- Read10X(data.dir = data_dir)
OVX_E2_20 = CreateSeuratObject(counts = expression_matrix, project = "OVX_E2(S)", min.cells = 3, min.features = 200)
OVX_E2_20[["percent.mt"]] <- PercentageFeatureSet(OVX_E2_20, pattern = "^mt-")
OVX_E2_20 <- subset(OVX_E2_20, subset = nFeature_RNA > 500 & nCount_RNA > 1000 & percent.mt < 10)

### E2+PBDE 
data_dir <- "...your_folder/Saeki/data/OVX_E2_PBDE_20"
list.files(data_dir) # Should show barcodes.tsv, genes.tsv, and matrix.mtx
expression_matrix <- Read10X(data.dir = data_dir)
OVX_E2_PBDE_20 = CreateSeuratObject(counts = expression_matrix, project = "OVX_E2_PBDE(S)", min.cells = 3, min.features = 200)
OVX_E2_PBDE_20[["percent.mt"]] <- PercentageFeatureSet(OVX_E2_PBDE_20, pattern = "^mt-")
OVX_E2_PBDE_20 <- subset(OVX_E2_PBDE_20, subset = nFeature_RNA > 500 & nCount_RNA > 1000 & percent.mt < 10)

### E2+P4 
data_dir <- "...your_folder/Saeki/data/OVX_E2_P4_20"
list.files(data_dir) # Should show barcodes.tsv, genes.tsv, and matrix.mtx
expression_matrix <- Read10X(data.dir = data_dir)
OVX_E2_P4_20 = CreateSeuratObject(counts = expression_matrix, project = "OVX_E2_P4(S)", min.cells = 3, min.features = 200)
OVX_E2_P4_20[["percent.mt"]] <- PercentageFeatureSet(OVX_E2_P4_20, pattern = "^mt-")
OVX_E2_P4_20 <- subset(OVX_E2_P4_20, subset = nFeature_RNA > 500 & nCount_RNA > 1000 & percent.mt < 10)

### E2+P4+PBDE 
data_dir <- "...your_folder/Saeki/data/OVX_E2_P4_PBDE_20"
list.files(data_dir) # Should show barcodes.tsv, genes.tsv, and matrix.mtx
expression_matrix <- Read10X(data.dir = data_dir)
OVX_E2_P4_PBDE_20 = CreateSeuratObject(counts = expression_matrix, project = "OVX_E2_P4_PBDE(S)", min.cells = 3, min.features = 200)
OVX_E2_P4_PBDE_20[["percent.mt"]] <- PercentageFeatureSet(OVX_E2_P4_PBDE_20, pattern = "^mt-")
OVX_E2_P4_PBDE_20 <- subset(OVX_E2_P4_PBDE_20, subset = nFeature_RNA > 500 & nCount_RNA > 1000 & percent.mt < 10)

###
saveRDS(OVX_20, "OVX(S)/OVX(S).rds")
saveRDS(OVX_E2_20, "OVX_E2(S)/OVX_E2(S).rds")
saveRDS(OVX_E2_PBDE_20, "OVX_E2_PBDE(S)/OVX_E2_PBDE(S).rds")
saveRDS(OVX_E2_P4_20, "OVX_E2_P4(S)/OVX_E2_P4(S).rds")
saveRDS(OVX_E2_P4_PBDE_20, "OVX_E2_P4_PBDE(S)/OVX_E2_P4_PBDE(S).rds")

remove(data_dir, expression_matrix, OVX_20, OVX_E2_20, OVX_E2_PBDE_20, OVX_E2_P4_20, OVX_E2_P4_PBDE_20)


########################################################################
###### Cleaning of each sample #########################################
########################################################################
for(i in 1:26){
  dataset <- params$Dataset[i]
  PC <- params$PCs[i]
  res <- params$Res[i]
  pK <- params$pK[i]
  path <- paste(dataset, ".rds", sep = paste("/", dataset, sep = ""))
  hoge <- readRDS(path)
  
  ##
  hoge <- NormalizeData(hoge)
  hoge <- FindVariableFeatures(hoge, selection.method = "vst", nfeatures = 2000)
  hoge <- ScaleData(hoge, features = rownames(hoge))
  hoge <- RunPCA(hoge, features = VariableFeatures(object = hoge))
  hoge <- RunUMAP(hoge, dims=1:PC)
  hoge <- FindNeighbors(hoge, dims = 1:PC)
  hoge <- FindClusters(hoge, resolution = res)
  
  ## Basic characteristics
  p1 <- UMAPPlot(hoge, label=T, label.size=8)+
    theme(plot.title = element_text(size=20, face="bold"),
          axis.text=element_text(size=14),
          axis.title=element_text(size=16,face="bold"))+
    ggtitle(dataset)
  
  p2 <- VlnPlot(hoge, "nFeature_RNA",pt.size=0)+ 
    geom_boxplot(width=0.15, fill="white")+
    NoLegend()+
    ggtitle("nFeature_RNA")+
    xlab("")+
    ylab("Gene count")+ 
    theme(plot.title = element_text(size=20, face="bold"),
          axis.text=element_text(size=14),
          axis.title=element_text(size=16,face="bold"))
  
  p3 <- VlnPlot(hoge, "nCount_RNA",pt.size=0)+ 
    geom_boxplot(width=0.15, fill="white")+
    NoLegend()+
    ggtitle("nCount_RNA")+
    xlab("")+
    ylab("UMI count")+ 
    theme(plot.title = element_text(size=20, face="bold"),
          axis.text=element_text(size=14),
          axis.title=element_text(size=16,face="bold"))
  
  p4 <- VlnPlot(hoge, "percent.mt",pt.size=0)+ 
    geom_boxplot(width=0.15, fill="white")+
    NoLegend()+
    ggtitle("percent.mt")+
    xlab("")+
    ylab("Mitochondrial gene percentage")+ 
    theme(plot.title = element_text(size=20, face="bold"),
          axis.text=element_text(size=14),
          axis.title=element_text(size=16,face="bold"))
  
  #
  plot_grid(p1, p2, p3, p4, ncol=4, align="hv")
  ggsave(paste(dataset, "fig1.pdf", sep="/"), width = 20, height = 4)
  ggsave(paste(dataset, "fig1.tiff", sep="/"), width = 20, height = 4, dpi=300)
  
  ## Cell cycle analysis
  hoge <- CellCycleScoring(hoge, s.features = s.genes, g2m.features = g2m.genes, set.ident = TRUE)
  p5 <- UMAPPlot(hoge, group.by="Phase")+
    theme(plot.title = element_text(size=20, face="bold"),
          axis.text=element_text(size=14),
          axis.title=element_text(size=16,face="bold"),
          legend.text = element_text(size=14))+
    ggtitle(paste(dataset, "Cell_cycle"))
  stat <- as.data.frame(table(hoge$seurat_clusters, hoge@active.ident))
  p6 <- ggplot() + 
    geom_bar(aes(y = Freq, x = Var1, fill = Var2), position = "fill", data = stat, stat="identity")+
    theme(plot.title = element_text(size=20, face="bold"),
          axis.text=element_text(size=14),
          axis.title=element_text(size=16,face="bold"),
          legend.text = element_text(size=14))+
    xlab("Cluster")+
    ylab("Frequency")+ 
    labs(fill = "")+
    ggtitle(paste(dataset, "Cell_cycle"))
  
  #
  plot_grid(p5, p6, ncol=2, align="hv")
  ggsave(paste(dataset, "fig2.pdf", sep="/"), width = 10, height = 4)
  ggsave(paste(dataset, "fig2.tiff", sep="/"), width = 10, height = 4, dpi=300)
  
  Idents(hoge) <- "seurat_clusters"
  
  
  ## DEG analysis
  if(length(levels(hoge@active.ident))>1){
    markers <- FindAllMarkers(hoge, only.pos = TRUE, min.pct = 0.25, logfc.threshold = 0.25)
    top5 <- markers %>% group_by(cluster) %>% top_n(n = 5, wt = avg_logFC)
    palette <- wes_palette("Zissou1", 100, type = "continuous")
    p7 <- DoHeatmap(hoge, features = as.character(top5$gene), label = T) +
      scale_fill_gradientn(colors = palette)
    
    write.csv(markers, paste(dataset, "DEG.csv", sep = "/"))
    
    p7
    ggsave(paste(dataset, "fig3.pdf", sep="/"), width = 10, height = 8)
    ggsave(paste(dataset, "fig3.tiff", sep="/"), width = 10, height = 8, dpi=300)
    
  }
  
  
  ## Doublet finder
  sweep.res.list_data <- paramSweep_v3(hoge, PCs = 1:PC, sct = FALSE)
  sweep.stats_data <- summarizeSweep(sweep.res.list_data, GT = FALSE)
  bcmvn_data <- find.pK(sweep.stats_data)
  saveRDS(bcmvn_data, paste(dataset, "bcmvn_data.rds", sep = "/"))
  
  annotations <- hoge@active.ident
  homotypic.prop <- modelHomotypic(annotations) 
  nExp_poi <- round(0.2*length(colnames(x = hoge)))  ## Assuming 20% doublet formation rate - tailor for your dataset
  nExp_poi.adj <- round(nExp_poi*(1-homotypic.prop))
  hoge <- doubletFinder_v3(hoge, PCs = 1:PC, pN = 0.25, pK = pK, nExp = nExp_poi.adj, reuse.pANN = FALSE, sct = FALSE)
  
  p8 <-UMAPPlot(hoge, group.by=paste(paste("DF.classifications_0.25", pK, sep = "_"), nExp_poi.adj, sep = "_"))+
    theme(plot.title = element_text(size=20, face="bold"),
          axis.text=element_text(size=14),
          axis.title=element_text(size=16,face="bold"),
          legend.text = element_text(size=14))+
    ggtitle(paste(dataset, "DoubletFinder"))
  stat <- as.data.frame(table(hoge$seurat_clusters,
                              hoge@meta.data[,colnames(hoge@meta.data) == paste(paste("DF.classifications_0.25", pK, sep = "_"), nExp_poi.adj, sep = "_")]))
  p9 <- ggplot() + 
    geom_bar(aes(y = Freq, x = Var1, fill = Var2), position = "fill", data = stat, stat="identity")+
    theme(plot.title = element_text(size=20, face="bold"),
          axis.text=element_text(size=14),
          axis.title=element_text(size=16,face="bold"),
          legend.text = element_text(size=14))+
    xlab("Cluster")+
    ylab("Frequency")+ 
    labs(fill = "")+
    ggtitle(paste(dataset, "DoubletFinder"))
  
  ##
  plot_grid(p8, p9, ncol=2, align="hv")
  ggsave(paste(dataset, "fig4.pdf", sep="/"), width = 10, height = 4)
  ggsave(paste(dataset, "fig4.tiff", sep="/"), width = 10, height = 4, dpi=300)
  
  ## Gene expression
  FP <- wes_palette("Zissou1", 5, type = "discrete")
  g1 <- FeaturePlot(hoge, "Krt14", cols = FP, 
                    pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
    NoAxes()+
    theme(plot.title = element_text(size=20, face="bold"),
          axis.text=element_text(size=14,face="bold"),
          axis.title=element_text(size=16,face="bold"))
  g2 <- FeaturePlot(hoge, "Acta2", cols = FP, 
                    pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
    NoAxes()+
    theme(plot.title = element_text(size=20, face="bold"),
          axis.text=element_text(size=14,face="bold"),
          axis.title=element_text(size=16,face="bold"))
  
  g3 <- FeaturePlot(hoge, "Krt18", cols = FP, 
                    pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
    NoAxes()+
    theme(plot.title = element_text(size=20, face="bold"),
          axis.text=element_text(size=14,face="bold"),
          axis.title=element_text(size=16,face="bold"))
  g4 <- FeaturePlot(hoge, "Csn3", cols = FP, 
                    pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
    NoAxes()+
    theme(plot.title = element_text(size=20, face="bold"),
          axis.text=element_text(size=14,face="bold"),
          axis.title=element_text(size=16,face="bold"))
  g5 <- FeaturePlot(hoge, "Elf5", cols = FP, 
                    pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
    NoAxes()+
    theme(plot.title = element_text(size=20, face="bold"),
          axis.text=element_text(size=14,face="bold"),
          axis.title=element_text(size=16,face="bold"))
  g6 <- FeaturePlot(hoge, "Areg", cols = FP, 
                    pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
    NoAxes()+
    theme(plot.title = element_text(size=20, face="bold"),
          axis.text=element_text(size=14,face="bold"),
          axis.title=element_text(size=16,face="bold"))
  g7 <- FeaturePlot(hoge, "Ly6d", cols = FP, 
                    pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
    NoAxes()+
    theme(plot.title = element_text(size=20, face="bold"),
          axis.text=element_text(size=14,face="bold"),
          axis.title=element_text(size=16,face="bold"))
  g8 <- FeaturePlot(hoge, "Mki67", cols = FP, 
                    pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
    NoAxes()+
    theme(plot.title = element_text(size=20, face="bold"),
          axis.text=element_text(size=14,face="bold"),
          axis.title=element_text(size=16,face="bold"))
  
  #
  plot_grid(g1,g2,g3,g4,g5,g6,g7,g8, ncol=4)
  ggsave(paste(dataset, "fig5.pdf", sep="/"), width = 20, height = 10)
  ggsave(paste(dataset, "fig5.tiff", sep="/"), width = 20, height = 10, dpi=300)
  

  ## Retained cells
  cells <- WhichCells(hoge, idents = params2[[as.character(dataset)]])
  
  ## Cleaned data saving
  hoge <- readRDS(path)
  hoge <- subset(hoge, cells = cells)
  saveRDS(hoge, paste(paste(dataset, dataset, sep = "/"), "cleaned.rds", sep = "_"))
  
  ## Clean environment
  remove(top5, sweep.stats_data, sweep.res.list_data, stat, bcmvn_data, hoge, markers,
         p1, p2, p3, p4, p5, p6, p7, p8, p9, g1, g2, g3, g4, g5, g6, g7, g8, 
         annotations, cells, dataset, FP, homotypic.prop, nExp_poi, nExp_poi.adj, path, PC, pK, res, palette)
}


# Extended analysis (for contaminating cell identification, not all datasets can go through this)
for(i in 1:26){
  dataset <- params$Dataset[i]
  PC <- params$PCs[i]
  res <- params$Res[i]
  pK <- params$pK[i]
  path <- paste(dataset, ".rds", sep = paste("/", dataset, sep = ""))
  hoge <- readRDS(path)
  
  ##
  hoge <- NormalizeData(hoge)
  hoge <- FindVariableFeatures(hoge, selection.method = "vst", nfeatures = 2000)
  hoge <- ScaleData(hoge, features = rownames(hoge))
  hoge <- RunPCA(hoge, features = VariableFeatures(object = hoge))
  hoge <- RunUMAP(hoge, dims=1:PC)
  hoge <- FindNeighbors(hoge, dims = 1:PC)
  hoge <- FindClusters(hoge, resolution = res)
  
  ## Marker expression
  FP <- wes_palette("Zissou1", 5, type = "discrete")
  g9 <- FeaturePlot(hoge, "Ptprc", cols = FP, 
                    pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
    NoAxes()+
    theme(plot.title = element_text(size=20, face="bold"),
          axis.text=element_text(size=14,face="bold"),
          axis.title=element_text(size=16,face="bold"))
  g10 <- FeaturePlot(hoge, "Cd52", cols = FP, 
                     pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
    NoAxes()+
    theme(plot.title = element_text(size=20, face="bold"),
          axis.text=element_text(size=14,face="bold"),
          axis.title=element_text(size=16,face="bold"))
  
  g11 <- FeaturePlot(hoge, "Vim", cols = FP, 
                     pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
    NoAxes()+
    theme(plot.title = element_text(size=20, face="bold"),
          axis.text=element_text(size=14,face="bold"),
          axis.title=element_text(size=16,face="bold"))
  g12 <- FeaturePlot(hoge, "Col1a1", cols = FP, 
                     pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
    NoAxes()+
    theme(plot.title = element_text(size=20, face="bold"),
          axis.text=element_text(size=14,face="bold"),
          axis.title=element_text(size=16,face="bold"))
  g13 <- FeaturePlot(hoge, "Cdh5", cols = FP, 
                     pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
    NoAxes()+
    theme(plot.title = element_text(size=20, face="bold"),
          axis.text=element_text(size=14,face="bold"),
          axis.title=element_text(size=16,face="bold"))
  g14 <- FeaturePlot(hoge, "Des", cols = FP, 
                     pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
    NoAxes()+
    theme(plot.title = element_text(size=20, face="bold"),
          axis.text=element_text(size=14,face="bold"),
          axis.title=element_text(size=16,face="bold"))
  
  #
  plot_grid(g9, g10, g11, g12, g13, g14, ncol=3)
  ggsave(paste(dataset, "fig6.pdf", sep="/"), width = 15, height = 10)
  ggsave(paste(dataset, "fig6.tiff", sep="/"), width = 15, height = 10, dpi=300)

  ## Clean environment
  remove(hoge, g9, g10, g11, g12, g13, g14, dataset, path, PC, pK, res, FP)
}


########################################################################
###### Merged data preparation #########################################
########################################################################
## Giraddi
E16 <- readRDS("Embryonic_d16(G)/Embryonic_d16(G)_cleaned.rds")
E18 <- readRDS("Embryonic_d18(G)/Embryonic_d18(G)_cleaned.rds")
P4 <- readRDS("Postnatal_d4(G)/Postnatal_d4(G)_cleaned.rds")
Adu1 <- readRDS("Adult_1(G)/Adult_1(G)_cleaned.rds")
Adu2 <- readRDS("Adult_2(G)/Adult_2(G)_cleaned.rds")
AduBas <- readRDS("Adult_Basal(G)/Adult_Basal(G)_cleaned.rds")
Giraddi <- merge(E16, c(E18, P4, Adu1, Adu2, AduBas), add.cell.ids = NULL, project = "Giraddi")
remove(E16, E18, P4, Adu1, Adu2, AduBas)

## Pal
AduEpi <- readRDS("Adult(P)/Adult(P)_cleaned.rds")
Pub1 <- readRDS("Puberty_1(P)/Puberty_1(P)_cleaned.rds")
Pub2 <- readRDS("Puberty_2(P)/Puberty_2(P)_cleaned.rds")
Diestrus <- readRDS("Adult_Diestrus(P)/Adult_Diestrus(P)_cleaned.rds")
Estrus <- readRDS("Adult_Estrus(P)/Adult_Estrus(P)_cleaned.rds")
Pal <- merge(AduEpi, c(Pub1, Pub2, Estrus, Diestrus), 
             add.cell.ids = c("Pal_Adult", "Pal_Pub1", "Pal_Pub2", "Pal_Estrus", "Pal_Diestrus"), project = "Pal")
remove(AduEpi, Pub1, Pub2, Diestrus, Estrus)

## Bach
NP1 <- readRDS("Nulliparous_1(B)/Nulliparous_1(B)_cleaned.rds")
NP2 <- readRDS("Nulliparous_2(B)/Nulliparous_2(B)_cleaned.rds")
G1 <- readRDS("Gestation_1(B)/Gestation_1(B)_cleaned.rds")
G2 <- readRDS("Gestation_2(B)/Gestation_2(B)_cleaned.rds")
L1 <- readRDS("Lactation_1(B)/Lactation_1(B)_cleaned.rds")
L2 <- readRDS("Lactation_2(B)/Lactation_2(B)_cleaned.rds")
PI1 <- readRDS("PostInvolution_1(B)/PostInvolution_1(B)_cleaned.rds")
PI2 <- readRDS("PostInvolution_2(B)/PostInvolution_2(B)_cleaned.rds")
Bach <- merge(NP1, y = c(NP2, G1, G2, L1, L2, PI1, PI2), 
              add.cell.ids = c("Bach_NP1", "Bach_NP2", "Bach_G1", "Bach_G2", "Bach_L1", "Bach_L2", "Bach_PI1", "Bach_PI2"), project = "Bach")
remove(NP1, NP2, G1, G2, L1, L2, PI1, PI2)

## TabulaMuris
Adu1 <- readRDS("Adult_1(TM)/Adult_1(TM)_cleaned.rds")
Adu2 <- readRDS("Adult_2(TM)/Adult_2(TM)_cleaned.rds")
TabulaMuris <- merge(Adu1, Adu2, 
              add.cell.ids = c("TM_Adu1", "TM_Adu2"), project = "TabulaMuris")
TabulaMuris@meta.data <- TabulaMuris@meta.data[,c(1:3, 14)]
remove(Adu1, Adu2)

## Saeki
OVX <- readRDS("OVX(S)/OVX(S)_cleaned.rds")
OVX_E2 <- readRDS("OVX_E2(S)/OVX_E2(S)_cleaned.rds")
OVX_E2_PBDE <- readRDS("OVX_E2_PBDE(S)/OVX_E2_PBDE(S)_cleaned.rds")
OVX_E2_P4 <- readRDS("OVX_E2_P4(S)/OVX_E2_P4(S)_cleaned.rds")
OVX_E2_P4_PBDE <- readRDS("OVX_E2_P4_PBDE(S)/OVX_E2_P4_PBDE(S)_cleaned.rds")
Saeki <- merge(OVX, y = c(OVX_E2, OVX_E2_PBDE, OVX_E2_P4, OVX_E2_P4_PBDE), 
              add.cell.ids = c("OVX", "OVX_E2", "OVX_E2_PBDE", "OVX_E2_P4", "OVX_E2_P4_PBDE"), project = "Saeki")
remove(OVX, OVX_E2, OVX_E2_PBDE, OVX_E2_P4, OVX_E2_P4_PBDE)


########################################################################
###### Cleaning of the merged data #####################################
########################################################################
params3 <- params[27:31,]
list <- list(Giraddi, Pal, Bach, TabulaMuris, Saeki)
names(list) <- params3$Dataset
remove(Giraddi, Pal, Bach, TabulaMuris, Saeki)

for(i in 1:5){
  dataset <- params3$Dataset[i]
  PC <- params3$PCs[i]
  res <- params3$Res[i]
  pK <- params3$pK[i]
  hoge <- list[[as.character(dataset)]]
  saveRDS(hoge, paste(paste(dataset, dataset, sep = "/"), ".rds", sep = ""))
  
  ##
  hoge <- NormalizeData(hoge)
  hoge <- FindVariableFeatures(hoge, selection.method = "vst", nfeatures = 2000)
  hoge <- ScaleData(hoge, features = rownames(hoge))
  hoge <- RunPCA(hoge, features = VariableFeatures(object = hoge))
  hoge <- RunUMAP(hoge, dims=1:PC)
  hoge <- FindNeighbors(hoge, dims = 1:PC)
  hoge <- FindClusters(hoge, resolution = res)
  
  ## Basic characteristics
  p1 <- UMAPPlot(hoge, label=T, label.size=8)+
    theme(plot.title = element_text(size=20, face="bold"),
          axis.text=element_text(size=14),
          axis.title=element_text(size=16,face="bold"))+
    ggtitle(dataset)
  
  p2 <- UMAPPlot(hoge, label=F, group.by = "orig.ident")+
    theme(plot.title = element_text(size=20, face="bold"),
          axis.text=element_text(size=14),
          axis.title=element_text(size=16,face="bold"))+
    ggtitle(dataset)
  
  p3 <- VlnPlot(hoge, "nCount_RNA",pt.size=0)+ 
    geom_boxplot(width=0.15, fill="white")+
    NoLegend()+
    ggtitle("nCount_RNA")+
    xlab("")+
    ylab("UMI count")+ 
    theme(plot.title = element_text(size=20, face="bold"),
          axis.text=element_text(size=14),
          axis.title=element_text(size=16,face="bold"))
  
  p4 <- VlnPlot(hoge, "percent.mt",pt.size=0)+ 
    geom_boxplot(width=0.15, fill="white")+
    NoLegend()+
    ggtitle("nFeature_RNA")+
    xlab("")+
    ylab("Gene count")+ 
    theme(plot.title = element_text(size=20, face="bold"),
          axis.text=element_text(size=14),
          axis.title=element_text(size=16,face="bold"))
  
  #
  plot_grid(p1, p2, p3, p4, ncol=4, align="hv")
  ggsave(paste(dataset, "fig1.pdf", sep="/"), width = 20, height = 4)
  ggsave(paste(dataset, "fig1.tiff", sep="/"), width = 20, height = 4, dpi=300)
  
  ## Cell cycle analysis
  hoge <- CellCycleScoring(hoge, s.features = s.genes, g2m.features = g2m.genes, set.ident = TRUE)
  p5 <- UMAPPlot(hoge, group.by="Phase")+
    theme(plot.title = element_text(size=20, face="bold"),
          axis.text=element_text(size=14),
          axis.title=element_text(size=16,face="bold"),
          legend.text = element_text(size=14))+
    ggtitle(paste(dataset, "Cell_cycle"))
  stat <- as.data.frame(table(hoge$seurat_clusters, hoge@active.ident))
  p6 <- ggplot() + 
    geom_bar(aes(y = Freq, x = Var1, fill = Var2), position = "fill", data = stat, stat="identity")+
    theme(plot.title = element_text(size=20, face="bold"),
          axis.text=element_text(size=14),
          axis.title=element_text(size=16,face="bold"),
          legend.text = element_text(size=14))+
    xlab("Cluster")+
    ylab("Frequency")+ 
    labs(fill = "")+
    ggtitle(paste(dataset, "Cell_cycle"))
  
  #
  plot_grid(p5, p6, ncol=2, align="hv")
  ggsave(paste(dataset, "fig2.pdf", sep="/"), width = 10, height = 4)
  ggsave(paste(dataset, "fig2.tiff", sep="/"), width = 10, height = 4, dpi=300)
  
  Idents(hoge) <- "seurat_clusters"
  
  
  ## DEG analysis
  if(length(levels(hoge@active.ident))>1){
    markers <- FindAllMarkers(hoge, only.pos = TRUE, min.pct = 0.25, logfc.threshold = 0.25)
    top5 <- markers %>% group_by(cluster) %>% top_n(n = 5, wt = avg_logFC)
    palette <- wes_palette("Zissou1", 100, type = "continuous")
    p7 <- DoHeatmap(hoge, features = as.character(top5$gene), label = T) +
      scale_fill_gradientn(colors = palette)
    
    write.csv(markers, paste(dataset, "DEG.csv", sep = "/"))
    
    p7
    ggsave(paste(dataset, "fig3.pdf", sep="/"), width = 10, height = 8)
    ggsave(paste(dataset, "fig3.tiff", sep="/"), width = 10, height = 8, dpi=300)
    
  }
  
  
  ## Doublet finder
  sweep.res.list_data <- paramSweep_v3(hoge, PCs = 1:PC, sct = FALSE)
  sweep.stats_data <- summarizeSweep(sweep.res.list_data, GT = FALSE)
  bcmvn_data <- find.pK(sweep.stats_data)
  saveRDS(bcmvn_data, paste(dataset, "bcmvn_data.rds", sep = "/"))
  
  annotations <- hoge@active.ident
  homotypic.prop <- modelHomotypic(annotations) 
  nExp_poi <- round(0.2*length(colnames(x = hoge)))  ## Assuming 20% doublet formation rate - tailor for your dataset
  nExp_poi.adj <- round(nExp_poi*(1-homotypic.prop))
  hoge <- doubletFinder_v3(hoge, PCs = 1:PC, pN = 0.25, pK = pK, nExp = nExp_poi.adj, reuse.pANN = FALSE, sct = FALSE)
  
  p8 <-UMAPPlot(hoge, group.by=paste(paste("DF.classifications_0.25", pK, sep = "_"), nExp_poi.adj, sep = "_"))+
    theme(plot.title = element_text(size=20, face="bold"),
          axis.text=element_text(size=14),
          axis.title=element_text(size=16,face="bold"),
          legend.text = element_text(size=14))+
    ggtitle(paste(dataset, "DoubletFinder"))
  stat <- as.data.frame(table(hoge$seurat_clusters,
                              hoge@meta.data[,colnames(hoge@meta.data) == paste(paste("DF.classifications_0.25", pK, sep = "_"), nExp_poi.adj, sep = "_")]))
  p9 <- ggplot() + 
    geom_bar(aes(y = Freq, x = Var1, fill = Var2), position = "fill", data = stat, stat="identity")+
    theme(plot.title = element_text(size=20, face="bold"),
          axis.text=element_text(size=14),
          axis.title=element_text(size=16,face="bold"),
          legend.text = element_text(size=14))+
    xlab("Cluster")+
    ylab("Frequency")+ 
    labs(fill = "")+
    ggtitle(paste(dataset, "DoubletFinder"))
  
  ##
  plot_grid(p8, p9, ncol=2, align="hv")
  ggsave(paste(dataset, "fig4.pdf", sep="/"), width = 10, height = 4)
  ggsave(paste(dataset, "fig4.tiff", sep="/"), width = 10, height = 4, dpi=300)
  
  ## Gene expression
  FP <- wes_palette("Zissou1", 5, type = "discrete")
  g1 <- FeaturePlot(hoge, "Krt14", cols = FP, 
                    pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
    NoAxes()+
    theme(plot.title = element_text(size=20, face="bold"),
          axis.text=element_text(size=14,face="bold"),
          axis.title=element_text(size=16,face="bold"))
  g2 <- FeaturePlot(hoge, "Acta2", cols = FP, 
                    pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
    NoAxes()+
    theme(plot.title = element_text(size=20, face="bold"),
          axis.text=element_text(size=14,face="bold"),
          axis.title=element_text(size=16,face="bold"))
  
  g3 <- FeaturePlot(hoge, "Krt18", cols = FP, 
                    pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
    NoAxes()+
    theme(plot.title = element_text(size=20, face="bold"),
          axis.text=element_text(size=14,face="bold"),
          axis.title=element_text(size=16,face="bold"))
  g4 <- FeaturePlot(hoge, "Csn3", cols = FP, 
                    pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
    NoAxes()+
    theme(plot.title = element_text(size=20, face="bold"),
          axis.text=element_text(size=14,face="bold"),
          axis.title=element_text(size=16,face="bold"))
  g5 <- FeaturePlot(hoge, "Elf5", cols = FP, 
                    pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
    NoAxes()+
    theme(plot.title = element_text(size=20, face="bold"),
          axis.text=element_text(size=14,face="bold"),
          axis.title=element_text(size=16,face="bold"))
  g6 <- FeaturePlot(hoge, "Areg", cols = FP, 
                    pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
    NoAxes()+
    theme(plot.title = element_text(size=20, face="bold"),
          axis.text=element_text(size=14,face="bold"),
          axis.title=element_text(size=16,face="bold"))
  g7 <- FeaturePlot(hoge, "Ly6d", cols = FP, 
                    pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
    NoAxes()+
    theme(plot.title = element_text(size=20, face="bold"),
          axis.text=element_text(size=14,face="bold"),
          axis.title=element_text(size=16,face="bold"))
  g8 <- FeaturePlot(hoge, "Mki67", cols = FP, 
                    pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
    NoAxes()+
    theme(plot.title = element_text(size=20, face="bold"),
          axis.text=element_text(size=14,face="bold"),
          axis.title=element_text(size=16,face="bold"))
  
  #
  plot_grid(g1,g2,g3,g4,g5,g6,g7,g8, ncol=4)
  ggsave(paste(dataset, "fig5.pdf", sep="/"), width = 20, height = 10)
  ggsave(paste(dataset, "fig5.tiff", sep="/"), width = 20, height = 10, dpi=300)
  
  
  ## Retained cells
  cells <- WhichCells(hoge, idents = params2[[as.character(dataset)]])
  
  ## Cleaned data saving
  hoge <- readRDS(paste(paste(dataset, dataset, sep = "/"), ".rds", sep = ""))
  hoge <- subset(hoge, cells = cells)
  hoge@meta.data[,"Dataset"] <- rep(as.character(dataset), length(row.names(hoge@meta.data)))
  saveRDS(hoge, paste(paste(dataset, dataset, sep = "/"), "cleaned.rds", sep = "_"))
  
  ## Clean environment
  remove(top5, sweep.stats_data, sweep.res.list_data, stat, bcmvn_data, hoge, markers,
         p1, p2, p3, p4, p5, p6, p7, p8, p9, g1, g2, g3, g4, g5, g6, g7, g8, 
         annotations, cells, dataset, FP, homotypic.prop, nExp_poi, nExp_poi.adj, PC, pK, res, palette)
}
